from typing import Literal

BorderWidth = Literal[
    '0',
    '2',
    '4',
    '8',
    '',
    'x-0',
    'x-2',
    'x-4',
    'x-8',
    'x',
    'y-0',
    'y-2',
    'y-4',
    'y-8',
    'y',
    's-0',
    's-2',
    's-4',
    's-8',
    's',
    'e-0',
    'e-2',
    'e-4',
    'e-8',
    'e',
    't-0',
    't-2',
    't-4',
    't-8',
    't',
    'r-0',
    'r-2',
    'r-4',
    'r-8',
    'r',
    'b-0',
    'b-2',
    'b-4',
    'b-8',
    'b',
    'l-0',
    'l-2',
    'l-4',
    'l-8',
    'l',
]
